@@ -2,7 +2,11 @@
 #Date and Time Setting Tool Copyright 2009,2011 by Tony Brijeski under the GPL V2
 # modified by skidoo and ppc - https://pastebin.com/1YmJHb95
 ###   NOTE: no validation is performed ~~ user can choose "Feb 31"
- 
+
+# Translation
+TEXTDOMAINDIR=/usr/share/locale
+TEXTDOMAIN=set_time-and_date.sh
+
 DIALOG="`which yad` --width 400 --center --undecorated"
 TITLE="--always-print-result --dialog-sep --title="
 TEXT="--text="
@@ -13,8 +17,19 @@ YESNO="--question "
 MSGBOX="--info "
 SCALE="--scale "
 PASSWORD="--entry --hide-text "
-TITLETEXT="Manage Date and Time Settings"
+TITLETEXT=$"Manage Date and Time Settings"
 testroot="`whoami`"   #  howdy       backticks galore
+DATE_TEXT=$"Date:"
+SETTIME_TEXT=$"Set Current Time"
+SETDATE_TEXT=$"Set Current Date"
+SETTZ_TEXT=$"Choose Time Zone (using cursor and enter keys)"
+SETAUTO_TEXT=$"Use Internet Time server to set automaticaly time/date"
+SETHOUR_TEXT=$"Move the slider to the correct Hour"
+SETMINUTE_TEXT=$"Move the slider to the correct Minute"
+SETTIMEZONE_TEXT=$"Select Time Zone"
+EXIT_TEXT=$"Quit"
+
+## TEXT TO BE DESPLAYED ##
  
 if [ "$testroot" != "root" ]; then
     gksu $0
@@ -27,13 +42,13 @@ MONTH="`date +%m`"
 YEAR="`date +%Y`"
 MINUTE="`date +%M`"
 HOUR="`date +%H`"
-SETCHOICE=`$DIALOG --no-buttons --center --height 300 $TITLE"$TITLETEXT" $MENU $TEXT" Manage Date and Time Settings\n Time Zone: $(cat /etc/timezone) \n Time: $HOUR:$MINUTE\n Date: $MONTH-$DAY-$YEAR\n\n" SETTIME " Set Current Time" SETDATE " Set Current Date"  SETTZ " Choose Time Zone (using cursor and enter keys)"  SETAUTO " Use Internet Time server to set automaticaly time/date" Exit " Quit"`
+SETCHOICE=`$DIALOG --no-buttons --center --height 300 $TITLE"$TITLETEXT" $MENU $TEXT" $TITLETEXT\n $DATE_TEXT\n $(date)\n\n" SETTIME " $SETTIME_TEXT" SETDATE " $SETDATE_TEXT"  SETTZ " $SETTZ_TEXT"  SETAUTO " $SETAUTO_TEXT" Exit " $EXIT_TEXT"`
 SETCHOICE=`echo $SETCHOICE | cut -d "|" -f 1`
  
 if [ "$SETCHOICE" = "SETTIME" ]; then
     HOUR="`date +%H`"
     HOUR=`echo $HOUR | sed -e 's/^0//g'`
-    SETHOUR=`$DIALOG --center $TITLE"$TITLETEXT" $SCALE --value=$HOUR --min-value=0 --max-value=23 $TEXT"Move the slider to the correct Hour"`
+    SETHOUR=`$DIALOG --center $TITLE"$TITLETEXT" $SCALE --value=$HOUR --min-value=0 --max-value=23 $TEXT"$SETHOUR_TEXT"`
     if [ "$?" = "0" ]; then
         if [ "${#SETHOUR}" = "1" ]; then
             SETHOUR="0$SETHOUR"
@@ -43,7 +58,7 @@ if [ "$SETCHOICE" = "SETTIME" ]; then
         MINUTE=`echo $MINUTE | sed -e 's/^0//g'`
     fi
  
-    SETMINUTE=`$DIALOG --center $TITLE"$TITLETEXT" $SCALE --value=$MINUTE --min-value=0 --max-value=59 $TEXT"Move the slider to the correct Minute"`
+    SETMINUTE=`$DIALOG --center $TITLE"$TITLETEXT" $SCALE --value=$MINUTE --min-value=0 --max-value=59 $TEXT"$SETMINUTE_TEXT"`
     if [ "$?" = "0" ]; then
         if [ "${#SETMINUTE}" = "1" ]; then
             SETMINUTE="0$SETMINUTE"
@@ -55,7 +70,7 @@ if [ "$SETCHOICE" = "SETTIME" ]; then
 fi
  
 if [ "$SETCHOICE" = "SETDATE" ]; then
-    var=`$DIALOG --form --separator="" --date-format="%Y%m%d" --field="Date:":DT`
+    var=`$DIALOG --form --separator="" --date-format="%Y%m%d" --field="$DATE_TEXT":DT`
 SETYEAR=$(echo ${var:0:4})
 SETMONTH=$(echo ${var:4:2})
 SETDAY=$(echo ${var:6:2})
@@ -71,9 +86,9 @@ sudo date -s "$(wget -qSO- --max-redirect=0 google.com 2>&1 | grep Date: | cut -
 fi
  
 if [ "$SETCHOICE" = "SETTZ" ]; then
-sudo roxterm --hide-menubar -z 0.75 -T " Select Time Zone" -e /bin/bash -c "dpkg-reconfigure tzdata"
+sudo roxterm --hide-menubar -z 0.75 -T " $SETTIMEZONE_TEXT" -e /bin/bash -c "dpkg-reconfigure tzdata"
  
 fi
 done
  
-exit 0
\ No newline at end of file
+exit 0
